@@ -32,6 +32,8 @@ type Project struct {
 	// TerraformCloudToken sets the Team API Token or User API Token so infracost can use it to access the plan.
 	// Only applicable for terraform cloud/enterprise users.
 	TerraformCloudToken string `yaml:"terraform_cloud_token,omitempty" envconfig:"INFRACOST_TERRAFORM_CLOUD_TOKEN"`
+	// TerragruntFlags set additional flags that should be passed to terragrunt.
+	TerragruntFlags string `envconfig:"INFRACOST_TERRAGRUNT_FLAGS"`
 	// UsageFile is the full path to usage file that specifies values for usage-based resources
 	UsageFile string `yaml:"usage_file,omitempty" ignored:"true"`
 	// TerraformUseState sets if the users wants to use the terraform state for infracost ops.
@@ -47,6 +49,7 @@ type Config struct {
 	LogLevel        string `yaml:"log_level,omitempty" envconfig:"INFRACOST_LOG_LEVEL"`
 	NoColor         bool   `yaml:"no_color,omitempty" envconfig:"INFRACOST_NO_COLOR"`
 	SkipUpdateCheck bool   `yaml:"skip_update_check,omitempty" envconfig:"INFRACOST_SKIP_UPDATE_CHECK"`
+	Parallelism     *int   `envconfig:"INFRACOST_PARALLELISM"`
 
 	APIKey                    string `envconfig:"INFRACOST_API_KEY"`
 	PricingAPIEndpoint        string `yaml:"pricing_api_endpoint,omitempty" envconfig:"INFRACOST_PRICING_API_ENDPOINT"`
@@ -54,6 +57,9 @@ type Config struct {
 	DashboardAPIEndpoint      string `yaml:"dashboard_api_endpoint,omitempty" envconfig:"INFRACOST_DASHBOARD_API_ENDPOINT"`
 	EnableDashboard           bool   `yaml:"enable_dashboard,omitempty" envconfig:"INFRACOST_ENABLE_DASHBOARD"`
 
+	TLSInsecureSkipVerify bool   `envconfig:"INFRACOST_TLS_INSECURE_SKIP_VERIFY"`
+	TLSCACertFile         string `envconfig:"INFRACOST_TLS_CA_CERT_FILE"`
+
 	Currency string `envconfig:"INFRACOST_CURRENCY"`
 
 	Projects      []*Project `yaml:"projects" ignored:"true"`
