@@ -15,12 +15,3 @@ func strPtr(s string) *string {
 func decimalPtr(d decimal.Decimal) *decimal.Decimal {
 	return &d
 }
-
-func stringInSlice(slice []string, s string) bool {
-	for _, b := range slice {
-		if b == s {
-			return true
-		}
-	}
-	return false
-}
