@@ -47,6 +47,8 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMDNSPrivateZoneRegistryItem(),
 	GetAzureRMDNSZoneRegistryItem(),
 	GetAzureRMEventHubsNamespaceRegistryItem(),
+	getAzureRMExpressRouteConnectionRegistryItem(),
+	getAzureRMExpressRouteGatewayRegistryItem(),
 	GetAzureRMFirewallRegistryItem(),
 	getAzureRMFrontdoorFirewallPolicyRegistryItem(),
 	getAzureRMFrontdoorRegistryItem(),
@@ -70,6 +72,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMMSSQLDatabaseRegistryItem(),
 	GetAzureRMMySQLServerRegistryItem(),
 	GetAzureRMNotificationHubNamespaceRegistryItem(),
+	getAzureRMPointToSiteVpnGatewayRegistryItem(),
 	GetAzureRMPostgreSQLFlexibleServerRegistryItem(),
 	GetAzureRMPostgreSQLServerRegistryItem(),
 	GetAzureRMPrivateDNSaRecordRegistryItem(),
@@ -88,12 +91,15 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMSynapseSparkPoolRegistryItem(),
 	GetAzureRMSynapseSQLPoolRegistryItem(),
 	GetAzureRMSynapseWorkspacRegistryItem(),
+	getAzureRMVirtualHubRegistryItem(),
 	GetAzureRMVirtualMachineScaleSetRegistryItem(),
 	GetAzureRMVirtualMachineRegistryItem(),
-	GetAzureRMVpnGatewayConnectionRegistryItem(),
-	GetAzureRMVpnGatewayRegistryItem(),
+	GetAzureRMVirtualNetworkGatewayConnectionRegistryItem(),
+	GetAzureRMVirtualNetworkGatewayRegistryItem(),
 	GetAzureRMWindowsVirtualMachineRegistryItem(),
 	GetAzureRMWindowsVirtualMachineScaleSetRegistryItem(),
+	getAzureRMVPNGatewayRegistryItem(),
+	getAzureRMVPNGatewayConnectionRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -250,17 +256,18 @@ var FreeResources = []string{
 
 	// Azure Networking
 	"azurerm_application_security_group",
+	"azurerm_local_network_gateway",
+	"azurerm_nat_gateway_public_ip_association",
+	"azurerm_nat_gateway_public_ip_prefix_association",
 	"azurerm_network_interface",
 	"azurerm_network_interface_security_group_association",
 	"azurerm_network_security_group",
 	"azurerm_network_security_rule",
 	"azurerm_private_link_service",
+	"azurerm_storage_account_network_rules",
 	"azurerm_subnet",
 	"azurerm_subnet_network_security_group_association",
 	"azurerm_virtual_network",
-	"azurerm_local_network_gateway",
-	"azurerm_nat_gateway_public_ip_association",
-	"azurerm_nat_gateway_public_ip_prefix_association",
 
 	// Azure Notification Hub
 	"azurerm_notification_hub",
@@ -317,6 +324,9 @@ var FreeResources = []string{
 	"azurerm_proximity_placement_group",
 	"azurerm_ssh_public_key",
 	"azurerm_marketplace_agreement",
+
+	// Azure WAN
+	"azurerm_virtual_wan",
 }
 
 var UsageOnlyResources = []string{}
