@@ -147,6 +147,9 @@ func (p *Parser) parseJSON(j []byte, usage map[string]*schema.UsageData) ([]*sch
 	pastResources := p.parseJSONResources(true, baseResources, usage, parsed, providerConf, conf, vars)
 	resources := p.parseJSONResources(false, baseResources, usage, parsed, providerConf, conf, vars)
 
+	resourceChanges := parsed.Get("resource_changes").Array()
+	pastResources = stripNonTargetResources(pastResources, resources, resourceChanges)
+
 	return pastResources, resources, nil
 }
 
@@ -181,6 +184,33 @@ func (p *Parser) loadUsageFileResources(u map[string]*schema.UsageData) []*schem
 	return resources
 }
 
+// stripNonTargetResources removes any past resources that don't exist in the
+// current resources or resource_changes in the Terraform plan. When Terraform
+// is run with `-target` then all resources still appear in prior_state but not
+// in planned_values. This makes sure we remove any non-target resources from
+// the past resources so that we only show resources matching the target.
+func stripNonTargetResources(pastResources []*schema.Resource, resources []*schema.Resource, resourceChanges []gjson.Result) []*schema.Resource {
+	resourceAddrMap := make(map[string]bool, len(resources))
+	for _, resource := range resources {
+		resourceAddrMap[resource.Name] = true
+	}
+
+	diffAddrMap := make(map[string]bool, len(resourceChanges))
+	for _, change := range resourceChanges {
+		diffAddrMap[change.Get("address").String()] = true
+	}
+
+	var filteredResources []*schema.Resource
+	for _, resource := range pastResources {
+		_, rOk := resourceAddrMap[resource.Name]
+		_, dOk := diffAddrMap[resource.Name]
+		if dOk || rOk {
+			filteredResources = append(filteredResources, resource)
+		}
+	}
+	return filteredResources
+}
+
 func (p *Parser) parseResourceData(isState bool, providerConf, planVals gjson.Result, conf gjson.Result, vars gjson.Result) map[string]*schema.ResourceData {
 	resources := make(map[string]*schema.ResourceData)
 
@@ -656,6 +686,18 @@ func parseKnownModuleRefs(resData map[string]*schema.ResourceData, conf gjson.Re
 			Attribute:        "launch_template",
 			ModuleSource:     "terraform-aws-modules/eks/aws",
 		},
+		{
+			SourceAddrSuffix: "aws_autoscaling_group.this",
+			DestAddrSuffix:   "aws_launch_template.this",
+			Attribute:        "launch_template",
+			ModuleSource:     "terraform-aws-modules/autoscaling/aws",
+		},
+		{
+			SourceAddrSuffix: "aws_autoscaling_group.this",
+			DestAddrSuffix:   "aws_launch_configuration.this",
+			Attribute:        "launch_configuration",
+			ModuleSource:     "terraform-aws-modules/autoscaling/aws",
+		},
 	}
 
 	for _, d := range resData {
