@@ -1,6 +1,7 @@
 package aws
 
 import (
+	"fmt"
 	"math"
 	"reflect"
 	"regexp"
@@ -25,6 +26,11 @@ func strVal(s *string) string {
 	return *s
 }
 
+// nolint:deadcode,unused
+func regexPtr(regex string) *string {
+	return strPtr(fmt.Sprintf("/%s/i", regex))
+}
+
 func intPtr(i int64) *int64 {
 	return &i
 }
