@@ -183,7 +183,7 @@ build_msg () {
       msg+="\n$update_msg\n\n"
     fi
     msg+="<sub>\n"
-    msg+="  Is this comment useful? <a href=\"https://www.infracost.io/feedback/submit?value=yes\" rel=\"noopener noreferrer\" target=\"_blank\">Yes</a>, <a href=\"https://www.infracost.io/feedback/submit?value=no\" rel=\"noopener noreferrer\" target=\"_blank\">No</a>\n"
+    msg+="  Is this comment useful? <a href=\"https://www.infracost.io/feedback/submit/?value=yes\" rel=\"noopener noreferrer\" target=\"_blank\">Yes</a>, <a href=\"https://www.infracost.io/feedback/submit/?value=no\" rel=\"noopener noreferrer\" target=\"_blank\">No</a>\n"
     msg+="</sub>\n"
   fi
   
